vfbLib.parsers.base.GaspParser
==============================

.. currentmodule:: vfbLib.parsers.base

.. autoclass:: GaspParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GaspParser.__init__
      ~GaspParser.parse
      ~GaspParser.parse_hex
      ~GaspParser.read_double
      ~GaspParser.read_doubles
      ~GaspParser.read_float
      ~GaspParser.read_floats
      ~GaspParser.read_int16
      ~GaspParser.read_int32
      ~GaspParser.read_int8
      ~GaspParser.read_str
      ~GaspParser.read_str_all
      ~GaspParser.read_uint16
      ~GaspParser.read_uint32
      ~GaspParser.read_uint8
      ~GaspParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GaspParser.encoding
      ~GaspParser.master_count
      ~GaspParser.stream
      ~GaspParser.ttStemsH_count
      ~GaspParser.ttStemsV_count
   
   